==> kv5500-0.3.tar.gz: kv5500-0.3/src/kv5500_photo.cpp <==
/*****************************************************************************
 *
 *  kv5500_photo - read a photo from kv5500 like phone.
 *
 * Copyright (c) 2006-2007 Hyo geol, Lee
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions are met:
 *
 *   1. Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the following disclaimer.
 *   2. Redistributions in binary form must reproduce the above copyright 
 * notice, this list of conditions and the following disclaimer in the 
 * documentation and/or other materials provided with the distribution.
 *   3. The name of the author may not be used to endorse or promote products
 * derived from this software without specific prior written permission.
 *
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" 
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE 
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE 
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF 
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS 
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN 
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
 * POSSIBILITY OF SUCH DAMAGE.
 *
 ****************************************************************************/
#include <sstream>

#include "kv5500.hpp"
#include "kv5500_photo.hpp"

using namespace KV5500;

PhotoInfoScanner::PhotoInfoScanner()
{
    numReqTempl_[0] = 0xfe;
    numReqTempl_[1] = 0x0a;
    numReqTempl_[2] = 0x07;
    numReqTempl_[3] = 0x00;
    numReqTempl_[4] = 0x7e;

    nameReqTempl_[0] = 0xfe;
    nameReqTempl_[1] = 0x0b;
    nameReqTempl_[2] = 0x07;
    nameReqTempl_[3] = 0x00;
    nameReqTempl_[4] = 0x00;
    nameReqTempl_[5] = 0x7e;

    sizeReqTempl_[0] = 0xfe;
    sizeReqTempl_[1] = 0x0d;
    sizeReqTempl_[2] = 0x07;
    sizeReqTempl_[3] = 0x00;
    sizeReqTempl_[4] = 0x00;
    sizeReqTempl_[5] = 0x00;
    sizeReqTempl_[6] = 0x00;
    sizeReqTempl_[7] = 0x7e;
}

PhotoGetFileScanner::PhotoGetFileScanner(unsigned int num)
    : GetFileScanner(num)
{
    numReqTempl_[0] = 0xfe;
    numReqTempl_[1] = 0x0a;
    numReqTempl_[2] = 0x07;
    numReqTempl_[3] = 0x00;
    numReqTempl_[4] = 0x7e;

    sizeReqTempl_[0] = 0xfe;
    sizeReqTempl_[1] = 0x0d;
    sizeReqTempl_[2] = 0x07;
    sizeReqTempl_[3] = 0x00;
    sizeReqTempl_[4] = 0x00;
    sizeReqTempl_[5] = 0x00;
    sizeReqTempl_[6] = 0x00;
    sizeReqTempl_[7] = 0xfe;

    prepareReqTempl_[0] = 0xfe;
    prepareReqTempl_[1] = 0x67;
    prepareReqTempl_[2] = 0xe6;
    prepareReqTempl_[3] = 0xfe;
    prepareReqTempl_[4] = 0x7e;

    transReqTempl_[0] = 0xfe;
    transReqTempl_[1] = 0x00;
    transReqTempl_[2] = 0x07;
    transReqTempl_[3] = 0x00;
    transReqTempl_[4] = 0x00;
    transReqTempl_[5] = 0x00;
    transReqTempl_[6] = 0x00;
    transReqTempl_[7] = 0x00;
    transReqTempl_[8] = 0x7e;
}

std::string PhotoGetFileScanner::GetFilename() const
{
    std::stringstream ss;

    ss << "kv5500-";

    ss.width(3);
    ss.fill('0');
    ss << GetReqNum();

    ss << "-" << time(0) << ".jpg";

    return ss.str();
}

bool KV5500::GetPhotoInfo(std::vector<FileInfo>& vec)
{
    Usb thisUsb;
    PhotoInfoScanner piScanner;

    if(!thisUsb.Scan(piScanner))
        return false;

    piScanner.GetInfo(vec);

    return true;
}

bool KV5500::SavePhotoFile(unsigned int num)
{
    Usb thisUsb;
    PhotoGetFileScanner pgScanner(num);

    if(!thisUsb.Scan(pgScanner))
        return false;

    return true;
}

==> kv5500-0.3.1.tar.gz: kv5500-0.3.1/src/kv5500_photo.cpp <==
/*****************************************************************************
 *
 *  kv5500_photo - read a photo from kv5500 like phone.
 *
 * Copyright (c) 2006-2007 Hyo geol, Lee
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without 
 * modification, are permitted provided that the following conditions are met:
 *
 *   1. Redistributions of source code must retain the above copyright notice,
 * this list of conditions and the following disclaimer.
 *   2. Redistributions in binary form must reproduce the above copyright 
 * notice, this list of conditions and the following disclaimer in the 
 * documentation and/or other materials provided with the distribution.
 *   3. The name of the author may not be used to endorse or promote products
 * derived from this software without specific prior written permission.
 *
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" 
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE 
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE 
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE 
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF 
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS 
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN 
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) 
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE 
 * POSSIBILITY OF SUCH DAMAGE.
 *
 ****************************************************************************/
#include <sstream>

#include "kv5500.hpp"
#include "kv5500_photo.hpp"

using namespace KV5500;

const char PhotoInfo::numReqTempl_[5] = { 0xfe, 0x0a, 0x07, 0x00, 0x7e };
const char PhotoInfo::nameReqTempl_[6] = { 0xfe, 0x0b, 0x07, 0x00, 0x00,
                                           0x7e };
const char PhotoInfo::sizeReqTempl_[8] = { 0xfe, 0x0d, 0x07, 0x00, 0x00, 
                                           0x00, 0x00, 0x7e };
const char PhotoInfo::prepareReqTempl_[5] = { 0xfe, 0x67, 0xe6, 0xfe, 0x7e };
const char PhotoInfo::transReqTempl_[9] = { 0xfe, 0x00, 0x07, 0x00, 0x00,
                                            0x00, 0x00, 0x00, 0x7e };

std::string PhotoFilenameGenerator::GetFilename(unsigned int num)
{
    std::stringstream ss;

    ss << "kv5500-";

    ss.width(3);
    ss.fill('0');
    ss << num;

    ss << "-" << time(0) << ".jpg";

    return ss.str();
}

bool KV5500::GetPhotoInfo(std::vector<FileInfo>& vec)
{
    Usb thisUsb;
    PhotoInfoScanner piScanner;

    if(!thisUsb.Scan(piScanner))
        return false;

    piScanner.GetInfo(vec);

    return true;
}

bool KV5500::SavePhotoFile(unsigned int num)
{
    Usb thisUsb;

    PhotoFilenameGenerator ng;
    ConsoleDisplay cd;
    PhotoGetFileScanner pgScanner(num, ng, cd);

    if(!thisUsb.Scan(pgScanner))
        return false;

    return true;
}
